@@ -1,6 +1,6 @@
 """KayPENTAX Disordered Voice Database Reader module"""
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 import pandas as pd
 from os import path
@@ -274,7 +274,7 @@ def query(subset=None, include_diagnoses=False, **filters):
         try:
             df = df[subset]
         except:
-            ValueError(
+            raise ValueError(
                 f'At least one label in the "subset" argument is invalid: {subset}'
             )
 
